![Zenroom](https://github.com/dyne/Zenroom/raw/master/docs/_media/images/zenroom_logo.png)

## Language bindings

Updated on official repositories:
- [Zenroom in NodeJS](https://www.npmjs.com/package/zenroom) :: `npm install zenroom`
- [Zenroom in Python](https://pypi.org/project/zenroom/) :: `pip install zenroom`
- [Zenroom in Go](https://github.com/dyne/Zenroom/blob/master/bindings/golang/zenroom/README.md) :: `go get github.com/dyne/Zenroom/bindings/golang/zenroom`
- [Zenroom in Rust](https://docs.rs/crate/zenroom/latest) :: see [our test example](https://github.com/dyne/Zenroom/tree/master/test/zenroom_exec_rs)

